@@ -70,6 +70,12 @@ vms:
     returned: always
     type: complex
     contains:
+        additional_capabilities:
+            description:
+                - Enables or disables a capability on the virtual machine.
+            type: dict
+            returned: always
+            sample: {ultra_ssd_enabled: False}
         admin_username:
             description:
                 - Administrator user name.
@@ -244,6 +250,12 @@ vms:
             returned: always
             type: dict
             sample: { "key1":"value1" }
+        vm_agent_version:
+            description:
+                - Version of the Azure VM Agent (waagent) running inside the VM.
+            returned: always
+            type: str
+            sample: '2.9.1.1'
         vm_size:
             description:
                 - Virtual machine size.
@@ -459,6 +471,11 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
 
         new_result = {}
 
+        if instance.get('vm_agent') is not None:
+            new_result['vm_agent_version'] = instance['vm_agent'].get('vm_agent_version')
+        else:
+            new_result['vm_agent_version'] = 'Unknown'
+
         if vm.security_profile is not None:
             new_result['security_profile'] = dict()
             if vm.security_profile.encryption_at_host is not None:
@@ -483,6 +500,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         new_result['vm_size'] = result['hardware_profile']['vm_size']
         new_result['proximityPlacementGroup'] = result.get('proximity_placement_group')
         new_result['zones'] = result.get('zones', None)
+        new_result['additional_capabilities'] = result.get('additional_capabilities')
         os_profile = result.get('os_profile')
         if os_profile is not None:
             new_result['admin_username'] = os_profile.get('admin_username')
