@@ -59,7 +59,8 @@ options:
             pass a list with single element like - 10.197.156.22. For CIDR based discovery, we should pass a list with
             single element like - 10.197.156.22/22. For RANGE based discovery, we should pass a list with single element
             and range like - 10.197.156.1-10.197.156.100. For MULTI RANGE based discovery, we should pass a list with multiple
-            elementd like - 10.197.156.1-10.197.156.100 and in next line - 10.197.157.1-10.197.157.100.
+            elementd like - 10.197.156.1-10.197.156.100 and in next line - 10.197.157.1-10.197.157.100. Maximum of 8 IP address ranges
+            are allowed.
         type: list
         elements: str
         required: true
@@ -328,7 +329,7 @@ options:
         default: False
 requirements:
 - dnacentersdk == 2.6.10
-- python >= 3.5
+- python >= 3.9
 notes:
   - SDK Method used are
     discovery.Discovery.get_all_global_credentials_v2,
@@ -721,6 +722,43 @@ class Discovery(DnacBase):
         self.status = "success"
         return self
 
+    def validate_ip4_address_list(self):
+        """
+        Validates each ip adress paased in the IP_address_list passed by the user before preprocessing it
+        """
+
+        ip_address_list = self.validated_config[0].get('ip_address_list')
+        for ip in ip_address_list:
+            if '/' in ip:
+                ip = ip.split("/")[0]
+            if '-' in ip:
+                if len(ip.split('-')) == 2:
+                    ip1, ip2 = ip.split('-')
+                    if self.is_valid_ipv4(ip1) is False:
+                        msg = "IP address {0} is not valid".format(ip1)
+                        self.log(msg, "CRITICAL")
+                        self.module.fail_json(msg=msg)
+                    if self.is_valid_ipv4(ip2) is False:
+                        msg = "IP address {0} is not valid".format(ip2)
+                        self.log(msg, "CRITICAL")
+                        self.module.fail_json(msg=msg)
+                    ip1_parts = list(map(int, ip1.split('.')))
+                    ip2_parts = list(map(int, ip2.split('.')))
+                    for part in range(4):
+                        if ip1_parts[part] > ip2_parts[part]:
+                            msg = "Incorrect range passed: {0}. Please pass correct IP address range".format(ip)
+                            self.log(msg, "CRITICAL")
+                            self.module.fail_json(msg=msg)
+                else:
+                    msg = "Provided range '{0}' is incorrect. IP address range should have only upper and lower limit values".format(ip)
+                    self.log(msg, "CRITICAL")
+                    self.module.fail_json(msg=msg)
+            if self.is_valid_ipv4(ip) is False and '-' not in ip:
+                msg = "IP address {0} is not valid".format(ip)
+                self.log(msg, "CRITICAL")
+                self.module.fail_json(msg=msg)
+        self.log("All the IP addresses passed are correct", "INFO")
+
     def get_creds_ids_list(self):
         """
         Retrieve the list of credentials IDs associated with class instance.
@@ -934,6 +972,7 @@ class Discovery(DnacBase):
             family="discovery",
             function='get_all_global_credentials_v2',
             params=self.validated_config[0].get('headers'),
+            op_modifies=True
         )
         response = response.get('response')
         self.log("The Global credentials response from 'get all global credentials v2' API is {0}".format(str(response)), "DEBUG")
@@ -1022,6 +1061,10 @@ class Discovery(DnacBase):
             else:
                 self.preprocess_device_discovery_handle_error()
         else:
+            if len(ip_address_list) > 8:
+                msg = "Maximum of 8 IP ranges are allowed."
+                self.log(msg, "CRITICAL")
+                self.module.fail_json(msg=msg)
             new_ip_collected = []
             for ip in ip_address_list:
                 if len(str(ip).split("-")) != 2:
@@ -1267,11 +1310,11 @@ class Discovery(DnacBase):
         self.log("Task Id of the API task created is {0}".format(result.response.get('taskId')), "INFO")
         return result.response.get('taskId')
 
-    def get_task_status(self, task_id=None):
+    def get_merged_task_status(self, task_id=None):
         """
-        Monitor the status of a task in the Cisco Catalyst Center. It checks the task
-        status periodically until the task is no longer 'In Progress'.
-        If the task encounters an error or fails, it immediately fails the
+        Monitor the status of a task of creation of dicovery in the Cisco Catalyst Center.
+        It checks the task status periodically until the task is no longer 'In Progress'
+        or other states. If the task encounters an error or fails, it immediately fails the
         module and returns False.
 
         Parameters:
@@ -1288,9 +1331,10 @@ class Discovery(DnacBase):
                 family="task",
                 function='get_task_by_id',
                 params=params,
+                op_modifies=True,
             )
             response = response.response
-            self.log("Task status for the task id {0} is {1}".format(str(task_id), str(response)), "INFO")
+            self.log("Task status for the task id {0} is {1}, is_error: {2}".format(str(task_id), str(response), str(response.get('isError'))), "INFO")
             if response.get('isError') or re.search(
                 'failed', response.get('progress'), flags=re.IGNORECASE
             ):
@@ -1299,17 +1343,62 @@ class Discovery(DnacBase):
                 self.log(msg, "CRITICAL")
                 self.module.fail_json(msg=msg)
                 return False
+
             self.log("Task status for the task id (before checking status) {0} is {1}".format(str(task_id), str(response)), "INFO")
             progress = response.get('progress')
-            if progress in ('In Progress', 'Inventory service initiating discovery'):
-                time.sleep(3)
-                continue
-            else:
+            try:
+                progress_value = int(progress)
                 result = True
-                self.log("The Process is completed", "INFO")
-                break
-        self.result.update(dict(discovery_task=response))
-        return result
+                self.log("The discovery process is completed", "INFO")
+                self.result.update(dict(discovery_task=response))
+                return result
+            except Exception:
+                self.log("The progress status is {0}, continue to check the status after 3 seconds. Putting into sleep for 3 seconds".format(progress))
+                time.sleep(3)
+
+    def get_deleted_task_status(self, task_id=None):
+        """
+        Monitor the status of a task of deletion of dicovery in the Cisco Catalyst Center.
+        It checks the itask status periodically until the task is 'Discovery deleted successfully'.
+        If the task encounters an error or fails, it immediately fails the module and returns False.
+
+        Parameters:
+          - task_id: The ID of the task to monitor.
+
+        Returns:
+          - result: True if the task completed successfully, False otherwise.
+        """
+
+        result = False
+        params = dict(task_id=task_id)
+        while True:
+            response = self.dnac_apply['exec'](
+                family="task",
+                function='get_task_by_id',
+                params=params,
+                op_modifies=True,
+            )
+            response = response.response
+            self.log("Task status for the task id {0} is {1}, is_error: {2}".format(str(task_id), str(response), str(response.get('isError'))), "INFO")
+            if response.get('isError') or re.search(
+                'failed', response.get('progress'), flags=re.IGNORECASE
+            ):
+                msg = 'Discovery task with id {0} has not completed - Reason: {1}'.format(
+                    task_id, response.get("failureReason"))
+                self.log(msg, "CRITICAL")
+                self.module.fail_json(msg=msg)
+                return False
+
+            self.log("Task status for the task id (before checking status) {0} is {1}".format(str(task_id), str(response)), "INFO")
+            progress = response.get('progress')
+            if re.search('Discovery deleted successfully.', response.get('progress')):
+                result = True
+                self.log("The discovery process is completed", "INFO")
+                self.result.update(dict(discovery_task=response))
+                return result
+
+            self.log("The progress status is {0}, continue to check the status after 3 seconds. Putting into sleep for 3 seconds".format(progress))
+            time.sleep(3)
 
     def lookup_discovery_by_range_via_name(self):
         """
@@ -1336,7 +1425,8 @@ class Discovery(DnacBase):
                 response_part = self.dnac_apply['exec'](
                     family="discovery",
                     function='get_discoveries_by_range',
-                    params=params
+                    params=params,
+                    op_modifies=True,
                 )
                 response["response"].extend(response_part["response"])
         else:
@@ -1349,7 +1439,8 @@ class Discovery(DnacBase):
             response = self.dnac_apply['exec'](
                 family="discovery",
                 function='get_discoveries_by_range',
-                params=params
+                params=params,
+                op_modifies=True,
             )
         self.log("Response of the get discoveries via range API is {0}".format(str(response)), "DEBUG")
 
@@ -1373,6 +1464,7 @@ class Discovery(DnacBase):
         """
 
         result = False
+        aborted = False
         discovery = self.lookup_discovery_by_range_via_name()
 
         if not discovery:
@@ -1383,17 +1475,25 @@ class Discovery(DnacBase):
 
         while True:
             discovery = self.lookup_discovery_by_range_via_name()
-            if discovery.get('discoveryCondition') == 'Complete':
+            discovery_condition = discovery.get('discoveryCondition')
+            if discovery_condition == 'Complete':
                 result = True
                 break
-
+            elif discovery_condition == 'Aborted':
+                aborted = True
+                break
             time.sleep(3)
 
         if not result:
-            msg = 'Cannot find any discovery task with name {0} -- Discovery result: {1}'.format(
-                str(self.validated_config[0].get("discovery_name")), str(discovery))
-            self.log(msg, "CRITICAL")
-            self.module.fail_json(msg=msg)
+            if aborted is True:
+                msg = 'Discovery with name {0} is aborted by the user on the GUI'.format(str(self.validated_config[0].get("discovery_name")))
+                self.log(msg, "CRITICAL")
+                self.module.fail_json(msg=msg)
+            else:
+                msg = 'Cannot find any discovery task with name {0} -- Discovery result: {1}'.format(
+                    str(self.validated_config[0].get("discovery_name")), str(discovery))
+                self.log(msg, "CRITICAL")
+                self.module.fail_json(msg=msg)
 
         self.result.update(dict(discovery_range=discovery))
         return discovery
@@ -1425,6 +1525,7 @@ class Discovery(DnacBase):
                 family="discovery",
                 function='get_discovered_network_devices_by_discovery_id',
                 params=params,
+                op_modifies=True,
             )
             devices = response.response
 
@@ -1495,6 +1596,7 @@ class Discovery(DnacBase):
             family="discovery",
             function="delete_discovery_by_id",
             params=params,
+            op_modifies=True,
         )
 
         self.log("Response collected from API 'delete_discovery_by_id': {0}".format(str(response)), "DEBUG")
@@ -1513,17 +1615,18 @@ class Discovery(DnacBase):
           - self: The instance of the class with updated attributes.
         """
 
+        self.validate_ip4_address_list()
         devices_list_info = self.get_devices_list_info()
         ip_address_list = self.preprocess_device_discovery(devices_list_info)
         exist_discovery = self.get_exist_discovery()
         if exist_discovery:
             params = dict(id=exist_discovery.get('id'))
             discovery_task_id = self.delete_exist_discovery(params=params)
-            complete_discovery = self.get_task_status(task_id=discovery_task_id)
+            complete_discovery = self.get_deleted_task_status(task_id=discovery_task_id)
 
         discovery_task_id = self.create_discovery(
             ip_address_list=ip_address_list)
-        complete_discovery = self.get_task_status(task_id=discovery_task_id)
+        complete_discovery = self.get_merged_task_status(task_id=discovery_task_id)
         discovery_task_info = self.get_discoveries_by_range_until_success()
         result = self.get_discovery_device_info(discovery_id=discovery_task_info.get('id'))
         self.result["changed"] = True
@@ -1576,7 +1679,7 @@ class Discovery(DnacBase):
 
             params = dict(id=exist_discovery.get('id'))
             discovery_task_id = self.delete_exist_discovery(params=params)
-            complete_discovery = self.get_task_status(task_id=discovery_task_id)
+            complete_discovery = self.get_deleted_task_status(task_id=discovery_task_id)
             self.result["changed"] = True
             self.result['msg'] = "Successfully deleted discovery"
             self.result['diff'] = self.validated_config
@@ -1611,7 +1714,8 @@ class Discovery(DnacBase):
         response = self.dnac_apply['exec'](
             family="discovery",
             function='get_discovery_by_id',
-            params=params
+            params=params,
+            op_modifies=True,
         )
         discovery_name = config.get('discovery_name')
         if response:
