@@ -120,7 +120,7 @@ options:
 
 requirements:
 - dnacentersdk == 2.4.5
-- python >= 3.5
+- python >= 3.9
 notes:
   - SDK Method used are
     sites.Sites.create_site,
@@ -488,6 +488,7 @@ class Site(DnacBase):
             response = self.dnac._exec(
                 family="sites",
                 function='get_site',
+                op_modifies=True,
                 params={"name": self.want.get("site_name")},
             )
 
@@ -806,12 +807,18 @@ class Site(DnacBase):
         else:
             # Creating New Site
             site_params = self.want.get("site_params")
-            if site_params['site']['building']:
-                building_details = {}
-                for key, value in site_params['site']['building'].items():
-                    if value is not None:
-                        building_details[key] = value
-                site_params['site']['building'] = building_details
+            try:
+                if site_params['site']['building']:
+                    building_details = {}
+                    for key, value in site_params['site']['building'].items():
+                        if value is not None:
+                            building_details[key] = value
+                    site_params['site']['building'] = building_details
+            except Exception as e:
+                site_type = site_params['type']
+                site_name = site_params['site'][site_type]['name']
+                self.log("""The site '{0}' is not categorized as a building; hence, there is no need to filter out 'None'
+                            values from the 'site_params' dictionary.""".format(site_name), "INFO")
 
             response = self.dnac._exec(
                 family="sites",
@@ -876,6 +883,7 @@ class Site(DnacBase):
             response = self.dnac._exec(
                 family="sites",
                 function="delete_site",
+                op_modifies=True,
                 params={"site_id": site_id},
             )
 
@@ -940,6 +948,7 @@ class Site(DnacBase):
         mem_response = self.dnac._exec(
             family="sites",
             function="get_membership",
+            op_modifies=True,
             params={"site_id": site_id},
         )
         site_response = mem_response.get("site").get("response")
