@@ -21,7 +21,7 @@ options:
             - If the value is not specified in the task, the value of environment variable E(DOCKER_HOST) will be used
               instead. If the environment variable is not set, the default value will be used.
         type: str
-        default: unix://var/run/docker.sock
+        default: unix:///var/run/docker.sock
         aliases: [ docker_url ]
     tls_hostname:
         description:
@@ -29,6 +29,8 @@ options:
             - If the value is not specified in the task, the value of environment variable E(DOCKER_TLS_HOSTNAME) will
               be used instead. If the environment variable is not set, the default value will be used.
             - Note that this option had a default value V(localhost) in older versions. It was removed in community.docker 3.0.0.
+            - B(Note:) this option is no longer supported for Docker SDK for Python 7.0.0+. Specifying it with Docker SDK for
+              Python 7.0.0 or newer will lead to an error.
         type: str
     api_version:
         description:
@@ -46,13 +48,15 @@ options:
               instead. If the environment variable is not set, the default value will be used.
         type: int
         default: 60
-    ca_cert:
+    ca_path:
         description:
             - Use a CA certificate when performing server verification by providing the path to a CA certificate file.
             - If the value is not specified in the task and the environment variable E(DOCKER_CERT_PATH) is set,
               the file C(ca.pem) from the directory specified in the environment variable E(DOCKER_CERT_PATH) will be used.
+            - This option was called O(ca_cert) and got renamed to O(ca_path) in community.docker 3.6.0. The old name has
+              been added as an alias and can still be used.
         type: path
-        aliases: [ tls_ca_cert, cacert_path ]
+        aliases: [ ca_cert, tls_ca_cert, cacert_path ]
     client_cert:
         description:
             - Path to the client's TLS certificate file.
@@ -72,6 +76,8 @@ options:
             - Provide a valid SSL version number. Default value determined by L(SSL Python module, https://docs.python.org/3/library/ssl.html).
             - If the value is not specified in the task, the value of environment variable E(DOCKER_SSL_VERSION) will be
               used instead.
+            - B(Note:) this option is no longer supported for Docker SDK for Python 7.0.0+. Specifying it with Docker SDK for
+              Python 7.0.0 or newer will lead to an error.
         type: str
     tls:
         description:
@@ -131,9 +137,11 @@ options:
     timeout:
         vars:
             - name: ansible_docker_timeout
-    ca_cert:
+    ca_path:
         vars:
             - name: ansible_docker_ca_cert
+            - name: ansible_docker_ca_path
+              version_added: 3.6.0
     client_cert:
         vars:
             - name: ansible_docker_client_cert
@@ -194,7 +202,7 @@ options:
             - If the value is not specified in the task, the value of environment variable E(DOCKER_HOST) will be used
               instead. If the environment variable is not set, the default value will be used.
         type: str
-        default: unix://var/run/docker.sock
+        default: unix:///var/run/docker.sock
         aliases: [ docker_url ]
     tls_hostname:
         description:
@@ -219,13 +227,15 @@ options:
               instead. If the environment variable is not set, the default value will be used.
         type: int
         default: 60
-    ca_cert:
+    ca_path:
         description:
             - Use a CA certificate when performing server verification by providing the path to a CA certificate file.
             - If the value is not specified in the task and the environment variable E(DOCKER_CERT_PATH) is set,
               the file C(ca.pem) from the directory specified in the environment variable E(DOCKER_CERT_PATH) will be used.
+            - This option was called O(ca_cert) and got renamed to O(ca_path) in community.docker 3.6.0. The old name has
+              been added as an alias and can still be used.
         type: path
-        aliases: [ tls_ca_cert, cacert_path ]
+        aliases: [ ca_cert, tls_ca_cert, cacert_path ]
     client_cert:
         description:
             - Path to the client's TLS certificate file.
@@ -293,3 +303,101 @@ requirements:
   - pyOpenSSL (when using TLS)
   - backports.ssl_match_hostname (when using TLS on Python 2)
 '''
+
+    # Docker doc fragment when using the Docker CLI
+    CLI_DOCUMENTATION = r'''
+options:
+    docker_cli:
+        description:
+            - Path to the Docker CLI. If not provided, will search for Docker CLI on the E(PATH).
+        type: path
+    docker_host:
+        description:
+            - The URL or Unix socket path used to connect to the Docker API. To connect to a remote host, provide the
+              TCP connection string. For example, V(tcp://192.0.2.23:2376). If TLS is used to encrypt the connection,
+              the module will automatically replace C(tcp) in the connection URL with C(https).
+            - If the value is not specified in the task, the value of environment variable E(DOCKER_HOST) will be used
+              instead. If the environment variable is not set, the default value will be used.
+        type: str
+        default: unix:///var/run/docker.sock
+        aliases: [ docker_url ]
+    tls_hostname:
+        description:
+            - When verifying the authenticity of the Docker Host server, provide the expected name of the server.
+            - If the value is not specified in the task, the value of environment variable E(DOCKER_TLS_HOSTNAME) will
+              be used instead. If the environment variable is not set, the default value will be used.
+        type: str
+    api_version:
+        description:
+            - The version of the Docker API running on the Docker Host.
+            - Defaults to the latest version of the API supported by this collection and the docker daemon.
+            - If the value is not specified in the task, the value of environment variable E(DOCKER_API_VERSION) will be
+              used instead. If the environment variable is not set, the default value will be used.
+        type: str
+        default: auto
+        aliases: [ docker_api_version ]
+    ca_path:
+        description:
+            - Use a CA certificate when performing server verification by providing the path to a CA certificate file.
+            - If the value is not specified in the task and the environment variable E(DOCKER_CERT_PATH) is set,
+              the file C(ca.pem) from the directory specified in the environment variable E(DOCKER_CERT_PATH) will be used.
+        type: path
+        aliases: [ ca_cert, tls_ca_cert, cacert_path ]
+    client_cert:
+        description:
+            - Path to the client's TLS certificate file.
+            - If the value is not specified in the task and the environment variable E(DOCKER_CERT_PATH) is set,
+              the file C(cert.pem) from the directory specified in the environment variable E(DOCKER_CERT_PATH) will be used.
+        type: path
+        aliases: [ tls_client_cert, cert_path ]
+    client_key:
+        description:
+            - Path to the client's TLS key file.
+            - If the value is not specified in the task and the environment variable E(DOCKER_CERT_PATH) is set,
+              the file C(key.pem) from the directory specified in the environment variable E(DOCKER_CERT_PATH) will be used.
+        type: path
+        aliases: [ tls_client_key, key_path ]
+    tls:
+        description:
+            - Secure the connection to the API by using TLS without verifying the authenticity of the Docker host
+              server. Note that if O(validate_certs) is set to V(true) as well, it will take precedence.
+            - If the value is not specified in the task, the value of environment variable E(DOCKER_TLS) will be used
+              instead. If the environment variable is not set, the default value will be used.
+        type: bool
+        default: false
+    validate_certs:
+        description:
+            - Secure the connection to the API by using TLS and verifying the authenticity of the Docker host server.
+            - If the value is not specified in the task, the value of environment variable E(DOCKER_TLS_VERIFY) will be
+              used instead. If the environment variable is not set, the default value will be used.
+        type: bool
+        default: false
+        aliases: [ tls_verify ]
+    # debug:
+    #     description:
+    #         - Debug mode
+    #     type: bool
+    #     default: false
+    cli_context:
+        description:
+            - The Docker CLI context to use.
+        type: str
+
+notes:
+  - Connect to the Docker daemon by providing parameters with each task or by defining environment variables.
+    You can define E(DOCKER_HOST), E(DOCKER_TLS_HOSTNAME), E(DOCKER_API_VERSION), E(DOCKER_CERT_PATH),
+    E(DOCKER_TLS), E(DOCKER_TLS_VERIFY) and E(DOCKER_TIMEOUT). If you are using docker machine, run the script shipped
+    with the product that sets up the environment. It will set these variables for you. See
+    U(https://docs.docker.com/machine/reference/env/) for more details.
+  - This module does B(not) use the L(Docker SDK for Python,https://docker-py.readthedocs.io/en/stable/) to
+    communicate with the Docker daemon. It directly calls the Docker CLI program.
+'''
+
+    # DEPRECATED: this will be removed from community.docker 4.0.0! Use with care!
+    SSL_VERSION_DEPRECATION = '''
+options:
+    ssl_version:
+        deprecated:
+            why: This was necessary a long time ago to handle problems with older TLS/SSL versions. It is no longer necessary nowadays.
+            version: 4.0.0
+'''
