@@ -26,7 +26,6 @@ description:
     L(create an issue in the community.routeros Issue Tracker,https://github.com/ansible-collections/community.routeros/issues/).
 extends_documentation_fragment:
   - community.routeros.api
-  - community.routeros.api.restrict
   - community.routeros.attributes
   - community.routeros.attributes.actiongroup_api
   - community.routeros.attributes.info_module
@@ -69,7 +68,6 @@ options:
         - interface ethernet switch port
         - interface gre
         - interface gre6
-        - interface l2tp-client
         - interface l2tp-server server
         - interface list
         - interface list member
@@ -127,12 +125,10 @@ options:
         - ip dhcp-server
         - ip dhcp-server config
         - ip dhcp-server lease
-        - ip dhcp-server matcher
         - ip dhcp-server network
         - ip dhcp-server option
         - ip dhcp-server option sets
         - ip dns
-        - ip dns adlist
         - ip dns static
         - ip firewall address-list
         - ip firewall connection tracking
@@ -177,7 +173,6 @@ options:
         - ipv6 firewall nat
         - ipv6 firewall raw
         - ipv6 nd
-        - ipv6 nd prefix
         - ipv6 nd prefix default
         - ipv6 route
         - ipv6 settings
@@ -191,7 +186,6 @@ options:
         - port remote-access
         - ppp aaa
         - ppp profile
-        - ppp secret
         - queue interface
         - queue simple
         - queue tree
@@ -205,18 +199,14 @@ options:
         - routing bgp peer
         - routing bgp template
         - routing filter
-        - routing filter num-list
         - routing filter rule
         - routing filter select-rule
         - routing id
-        - routing igmp-proxy
-        - routing igmp-proxy interface
         - routing mme
         - routing ospf area
         - routing ospf area range
         - routing ospf instance
         - routing ospf interface-template
-        - routing ospf static-neighbor
         - routing pimsm instance
         - routing pimsm interface-template
         - routing rip
@@ -227,7 +217,6 @@ options:
         - snmp community
         - system clock
         - system clock manual
-        - system health settings
         - system identity
         - system leds settings
         - system logging
@@ -237,7 +226,6 @@ options:
         - system ntp client servers
         - system ntp server
         - system package update
-        - system resource irq rps
         - system routerboard settings
         - system scheduler
         - system script
@@ -307,10 +295,6 @@ options:
     type: bool
     default: false
     version_added: 2.10.0
-  restrict:
-    description:
-      - Restrict output to entries matching the following criteria.
-    version_added: 2.18.0
 seealso:
   - module: community.routeros.api
   - module: community.routeros.api_facts
@@ -328,18 +312,6 @@ EXAMPLES = '''
     path: ip address
   register: ip_addresses
 
-- name: Print data for IP addresses
-  ansible.builtin.debug:
-    var: ip_addresses.result
-
-- name: Get IP addresses
-  community.routeros.api_info:
-    hostname: "{{ hostname }}"
-    password: "{{ password }}"
-    username: "{{ username }}"
-    path: ip address
-  register: ip_addresses
-
 - name: Print data for IP addresses
   ansible.builtin.debug:
     var: ip_addresses.result
@@ -380,12 +352,6 @@ from ansible_collections.community.routeros.plugins.module_utils._api_data impor
     split_path,
 )
 
-from ansible_collections.community.routeros.plugins.module_utils._api_helper import (
-    restrict_argument_spec,
-    restrict_entry_accepted,
-    validate_and_prepare_restrict,
-)
-
 try:
     from librouteros.exceptions import LibRouterosError
 except Exception:
@@ -411,7 +377,6 @@ def main():
         include_read_only=dict(type='bool', default=False),
     )
     module_args.update(api_argument_spec())
-    module_args.update(restrict_argument_spec())
 
     module = AnsibleModule(
         argument_spec=module_args,
@@ -440,7 +405,6 @@ def main():
     include_dynamic = module.params['include_dynamic']
     include_builtin = module.params['include_builtin']
     include_read_only = module.params['include_read_only']
-    restrict_data = validate_and_prepare_restrict(module, path_info)
     try:
         api_path = compose_api_path(api, path)
 
@@ -453,8 +417,6 @@ def main():
             if not include_builtin:
                 if entry.get('builtin', False):
                     continue
-            if not restrict_entry_accepted(entry, path_info, restrict_data):
-                continue
             if not unfiltered:
                 for k in list(entry):
                     if k == '.id':
