@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # Dell OpenManage Ansible Modules
-# Version 8.2.0
-# Copyright (C) 2022-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.1.0
+# Copyright (C) 2022-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # Redistribution and use in source and binary forms, with or without modification,
 # are permitted provided that the following conditions are met:
@@ -46,6 +46,7 @@ SYSTEM_RESET_URI = "/redfish/v1/Systems/{res_id}/Actions/ComputerSystem.Reset"
 MANAGER_JOB_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs?$expand=*($levels=1)"
 MANAGER_JOB_ID_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs/{0}"
 GET_IDRAC_FIRMWARE_VER_URI = "/redfish/v1/Managers/iDRAC.Embedded.1?$select=FirmwareVersion"
+HOSTNAME_REGEX = r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$"
 
 import time
 from datetime import datetime
@@ -76,6 +77,36 @@ def strip_substr_dict(odata_dict, chkstr='@odata.', case_sensitive=False):
     return odata_dict
 
 
+def config_ipv6(hostname):
+    ip_addr, port = hostname, None
+    if hostname.count(':') == 1:
+        ip_addr, port = hostname.split(':')
+    if not re.match(HOSTNAME_REGEX, ip_addr):
+        if ']:' in ip_addr:
+            ip_addr, port = ip_addr.split(']:')
+        ip_addr = ip_addr.strip('[]')
+        ip_addr = compress_ipv6(ip_addr)
+        if port is None or port == "":
+            hostname = "[{0}]".format(ip_addr)
+        else:
+            hostname = "[{0}]:{1}".format(ip_addr, port)
+    return hostname
+
+
+def compress_ipv6(ipv6_long):
+    groups = ipv6_long.split(':')
+    temp = []
+    for group in groups:
+        group = re.sub(r'^0+', '', group)
+        group = group.lower()
+        if 0 == len(group):
+            group = '0'
+        temp.append(group)
+    tempstr = ':'.join(temp)
+    ipv6_short = re.sub(r'(:0)+', ':', tempstr, 1)
+    return ipv6_short
+
+
 def job_tracking(rest_obj, job_uri, max_job_wait_sec=600, job_state_var=('LastRunStatus', 'Id'),
                  job_complete_states=(2060, 2020, 2090), job_fail_states=(2070, 2101, 2102, 2103),
                  job_running_states=(2050, 2040, 2030, 2100),
@@ -477,12 +508,14 @@ def get_current_time(redfish_obj):
     return curr_time, date_offset
 
 
-def xml_data_conversion(attr_dict, fqdd=None):
+def xml_data_conversion(attr_dict, fqdd=None, custom_payload_to_add=None):
     component = """<Component FQDD="{0}">{1}</Component>"""
     attr = ""
     for k, v in attr_dict.items():
         key = re.sub(r"\.(?!\d)", "#", k)
         attr += '<Attribute Name="{0}">{1}</Attribute>'.format(key, v)
+    if custom_payload_to_add:
+        attr += custom_payload_to_add
     root = component.format(fqdd, attr)
     return root
 
